glaxo: Relaxed glasso

Description Usage Arguments Value Examples

View source: R/glaxo.R

Description

An implementation of relaxed glasso based on the 'simple algorithm' for the relaxed lasso presented in section 2.2 of Meinshausen (2006)

Usage

1
glaxo(Y, S = NULL, n = NULL, nlambda_relaxed = 4, ic = "bic", ...)

Arguments

Y

A data.frame or matrix containing data. Specified if not supplying covariance matrix.

S

A covariance matrix. Specified if not supplying raw data.

n

Number of observations. Specified if not supplying raw data.

nlambda_relaxed

Number of lambdas to be generated in Step 2 of algorithm

ic

Information critera to be used for selecting model. See ggmncv in the GGMncv package

...

Other arguments to be passed on to ggmncv in the GGMncv package

Value

An object of classes glaxo, ggmncv, and default

Examples

1
2
3
4
5
data("bfi", package = "psych")
Y <- subset(bfi, select = -c(gender, education, age))
Y <- na.omit(Y)

model <- glaxo(Y)

josue-rodriguez/glaxo documentation built on Dec. 21, 2021, 2:22 a.m.