predict.glaxo: Predict method for glaxo object

Description Usage Arguments Value

View source: R/predict.R

Description

Generate predictions for new data based on glasso estimates

Usage

1
2
## S3 method for class 'glaxo'
predict(object, newdata, scale = TRUE, ...)

Arguments

object

An object of type glaxo

newdata

A data.frame or matrix with with same number of columns as the original data.

scale

Whether the newdata should be scaled. Default is true.

...

Currently ignored

Value

A list containing the predictions and associated coefficients

predictions

A matrix containing predictions for the new data

beta_matrix

A matrix where each (i,j)th element is the beta coefficient of variable j when predicting variable i. The diagonal elements encode the variances for the corresponding variables.


josue-rodriguez/glaxo documentation built on Dec. 21, 2021, 2:22 a.m.