Description Usage Arguments Value Examples
An implementation of relaxed glasso based on the 'simple algorithm' for the relaxed lasso presented in section 2.2 of Meinshausen (2006)
1 |
Y |
A |
S |
A covariance matrix. Specified if not supplying raw data. |
n |
Number of observations. Specified if not supplying raw data. |
nlambda_relaxed |
Number of lambdas to be generated in Step 2 of algorithm |
ic |
Information critera to be used for selecting model. See |
... |
Other arguments to be passed on to |
An object of classes glaxo, ggmncv, and default
1 2 3 4 5 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.