Description Usage Arguments Value
Generate predictions for new data based on glasso estimates
1 2 |
object |
An object of type |
newdata |
A |
scale |
Whether the newdata should be scaled. Default is true. |
... |
Currently ignored |
A list containing the predictions and associated coefficients
A matrix containing predictions for the new data
A matrix where each (i,j)th element is the beta coefficient of variable j when predicting variable i. The diagonal elements encode the variances for the corresponding variables.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.